@@ -16,7 +16,25 @@ sub should_inline_value
           ($_[1]->driver eq 'informix' || $_[2] =~ /^\w+\(.*\)$/)) ? 1 : 0;
 }
 
-sub parse_value  { shift; shift->parse_datetime_year_to_minute(@_)  }
+sub parse_value
+{
+  my($self, $db) = (shift, shift);
+
+  my $dt = $db->parse_datetime_year_to_minute(@_);
+
+  if($dt)
+  {
+    $dt->set_time_zone($self->time_zone || $db->server_time_zone)
+      if(UNIVERSAL::isa($dt, 'DateTime'));
+  }
+  else
+  {
+    $dt = Rose::DateTime::Util::parse_date($_[0], $self->time_zone || $db->server_time_zone)
+  }
+
+  return $dt;
+}
+
 sub format_value { shift; shift->format_datetime_year_to_minute(@_) }
 
 1;
@@ -41,7 +59,7 @@ Rose::DB::Object::Metadata::Column::DatetimeYearToMinute - Datetime year to minu
 
 Objects of this class store and manipulate metadata for "datetime year to minute" columns in a database.  Column metadata objects store information about columns (data type, size, etc.) and are responsible for creating object methods that manipulate column values.
 
-This class inherits from L<Rose::DB::Object::Metadata::Datetime>. Inherited methods that are not overridden will not be documented a second time here.  See the L<Rose::DB::Object::Metadata::Datetime> documentation for more information.
+This class inherits from L<Rose::DB::Object::Metadata::Column::Datetime>. Inherited methods that are not overridden will not be documented a second time here.  See the L<Rose::DB::Object::Metadata::Column::Datetime> documentation for more information.
 
 =head1 METHOD MAP
 
