@@ -8,7 +8,7 @@ use Rose::DB::Object::MakeMethods::Generic;
 use Rose::DB::Object::Metadata::Column;
 our @ISA = qw(Rose::DB::Object::Metadata::Column);
 
-our $VERSION = '0.03';
+our $VERSION = '0.711';
 
 __PACKAGE__->add_common_method_maker_argument_names
 (
@@ -31,6 +31,13 @@ sub type { 'set' }
 sub parse_value  { shift; shift->parse_set(@_)  }
 sub format_value { shift; shift->format_set(@_) }
 
+sub method_uses_formatted_key
+{
+  my($self, $type) = @_;
+  return 1  if($type eq 'get' || $type eq 'set' || $type eq 'get_set');
+  return 0;
+}
+
 1;
 
 __END__
