@@ -4,12 +4,13 @@ use strict;
 
 use Carp();
 
+use Clone::PP();
 use Rose::Object::MakeMethods::Generic;
 
 use Rose::DB::Object::Metadata::Object;
 our @ISA = qw(Rose::DB::Object::Metadata::Object);
 
-our $VERSION = '0.02';
+our $VERSION = '0.702';
 
 #
 # Class data
@@ -56,10 +57,48 @@ Rose::Object::MakeMethods::Generic->make_methods
 # Class methods
 #
 
-sub init_auto_method_types { shift->default_auto_method_types }
-
 our %Method_Maker_Info;
 
+OVERRIDE:
+{
+  my $orig_add_method = \&add_common_method_maker_argument_names;
+
+  no warnings 'redefine';
+  *add_common_method_maker_argument_names = sub
+  {
+    my($class) = shift;
+
+    if(@_ && $Method_Maker_Info{$class})
+    {      
+      foreach my $type (keys %{$Method_Maker_Info{$class}})
+      {
+        push(@{$Method_Maker_Info{$class}{$type}{'args'}}, @_);
+      }
+    }
+
+    $orig_add_method->($class, @_);
+  };
+
+  my $orig_delete_method = \&delete_common_method_maker_argument_names;
+
+  *delete_common_method_maker_argument_names = sub
+  {
+    my($class) = shift;
+
+    if(@_ && $Method_Maker_Info{$class})
+    {      
+      foreach my $type (keys %{$Method_Maker_Info{$class}})
+      {
+        delete @{$Method_Maker_Info{$class}{$type}{'args'}}{@_};
+      }
+    }
+
+    $orig_delete_method->($class, @_);
+  };
+}
+
+sub init_auto_method_types { shift->default_auto_method_types }
+
 # This is basically a Rose::Class::MakeMethods::Set::inherited_set
 # but it's keyed.  I'm only implementing a one-time superclass copy
 # here, instead of the more involved "inherited_set" version where
@@ -91,14 +130,16 @@ sub init_method_maker_info
         {
           next  unless($subclass_info->{$type});
 
-          foreach my $attr (qw(class type args))
+          foreach my $attr (qw(class type))
           {
             next  if(!$subclass_info->{$type}{$attr} ||
                      defined $info->{$type}{$attr});  
 
-            my $val = $subclass_info->{$type}{$attr};
-            $info->{$type}{$attr} = (ref $val && ref $val eq 'ARRAY') ? [ @$val ] : $val;
+            $info->{$type}{$attr} = Clone::PP::clone($subclass_info->{$type}{$attr});
           }
+
+          # Args come from an already-inhereted set
+          $info->{$type}{'args'} = [ $class->common_method_maker_argument_names ];
         }
       }
     }
